@@ -21,8 +21,6 @@ fi
 
 VIZDOOM_PK3_PATH="${BIN_PATH}/vizdoom.pk3"
 PYTHON_BIN_PATH="$(ls ${PACKAGE_DEST_DIRECTORY}/vizdoom*)"
-PYTHON_BIN_EXT="${PYTHON_BIN_PATH##*.}"
-PYTHON_BIN_DEST_PATH="${PACKAGE_DEST_PATH}/vizdoom.${PYTHON_BIN_EXT}"
 
 FREEDOOM_PATH="${SRC_PATH}/src/freedoom2.wad"
 SCENARIOS_DEST_DIR="${PACKAGE_DEST_PATH}/scenarios"
@@ -42,11 +40,11 @@ rm -rf ${PACKAGE_DEST_PATH}
 mkdir -p ${PACKAGE_DEST_PATH}
 
 cp ${PACKAGE_INIT_FILE_SRC} ${PACKAGE_DEST_PATH}
-cp ${PYTHON_BIN_PATH} ${PYTHON_BIN_DEST_PATH}
+cp ${PYTHON_BIN_PATH} ${PACKAGE_DEST_PATH}
 cp ${VIZDOOM_EXEC_PATH} ${PACKAGE_DEST_PATH}
 cp ${VIZDOOM_PK3_PATH} ${PACKAGE_DEST_PATH}
 cp ${FREEDOOM_PATH} ${PACKAGE_DEST_PATH}
 mkdir -p ${SCENARIOS_DEST_DIR}
-cp ${SCENARIOS_PATH}/*.wad  ${SCENARIOS_DEST_DIR}
-cp ${SCENARIOS_PATH}/*.cfg  ${SCENARIOS_DEST_DIR}
+cp ${SCENARIOS_PATH}/*.wad ${SCENARIOS_DEST_DIR}
+cp ${SCENARIOS_PATH}/*.cfg ${SCENARIOS_DEST_DIR}
 mv ${SCENARIOS_DEST_DIR}/bots.cfg ${PACKAGE_DEST_PATH}
